@@ -4,7 +4,8 @@
 # Copyright (c) Mariana Meireles.
 # Distributed under the terms of the Modified BSD License.
 
-from .cytoscape import CytoscapeWidget
+from .cytoscape import *
+
 from ._version import __version__, version_info
 
 from .nbextension import _jupyter_nbextension_paths
